#! /bin/sh

# Test pmldigital date/time offset option

tmpxml='tmp.xml'
../pmldigital -f 2004d05f001.jpg > $tmpxml
date0=`grep date $tmpxml | sed -e 's/ *<[^>]*>//g'`
time0=`grep time $tmpxml | sed -e 's/ *<[^>]*>//g'`
../pmldigital -f -t '+1d' 2004d05f001.jpg > $tmpxml
date1=`grep date $tmpxml | sed -e 's/ *<[^>]*>//g'`
if [ "$date1" != "" ]; then
  diff1=`expr \( substr $date1 9 2 \) - \( substr $date0 9 2 \)`
fi
../pmldigital -f -t '-2M' 2004d05f001.jpg > $tmpxml
date2=`grep date $tmpxml | sed -e 's/ *<[^>]*>//g'`
if [ "$date2" != "" ]; then
  diff2=`expr \( substr $date0 6 2 \) - \( substr $date2 6 2 \)`
fi
../pmldigital -f -t '-08s' 2004d05f001.jpg > $tmpxml
time1=`grep time $tmpxml | sed -e 's/ *<[^>]*>//g'`
if [ "$time1" != "" ]; then
  diff3=`expr \( substr $time0 7 2 \) - \( substr $time1 7 2 \)`
fi
../pmldigital -f -t '+3h' 2004d05f001.jpg > $tmpxml
time2=`grep time $tmpxml | sed -e 's/ *<[^>]*>//g'`
if [ "$time2" != "" ]; then
  diff4=`expr \( substr $time2 1 2 \) - \( substr $time0 1 2 \)`
fi
rm $tmpxml
es=0
if [ "$diff1" != "1" ]; then
  es=`expr $es + 1`
fi
if [ "$diff2" != "2" ]; then
  es=`expr $es + 1`
fi
if [ "$diff3" != 8 ]; then
  es=`expr $es + 1`
fi
if [ "$diff4" != 3 ]; then
  es=`expr $es + 1`
fi
exit $es
